@@ -8,4 +8,7 @@ def mango():
     print("Mangooooooo")
     
 def mango2():
-    print("Mer mangoooo")
\ No newline at end of file
+    print("Mer mangoooo")
+    
+def mango3():
+    print("Enda mer mangoooo")
\ No newline at end of file
